@@ -118,9 +118,9 @@ class BpmnDiagramGraphExport(object):
         :param node_params: dictionary with given intermediate catch event parameters,
         :param output_element: object representing BPMN XML 'intermediateCatchEvent' element.
         """
-        output_element.set(consts.Consts.parallel_multiple, node_params[consts.Consts.parallel_multiple])
-        output_element.set(consts.Consts.is_interrupting, node_params[consts.Consts.is_interrupting])
-        definitions = node_params[consts.Consts.event_definitions]
+        output_element.set(consts.Consts.parallel_multiple, node_params.get(consts.Consts.parallel_multiple))
+        output_element.set(consts.Consts.is_interrupting, node_params.get(consts.Consts.is_interrupting))
+        definitions = node_params.get(consts.Consts.event_definitions)
         for definition in definitions:
             definition_id = definition[consts.Consts.id]
             definition_type = definition[consts.Consts.definition_type]
@@ -341,6 +341,7 @@ class BpmnDiagramGraphExport(object):
             condition_expression.set(consts.Consts.id, condition_expression_params[consts.Consts.id])
             condition_expression.set(consts.Consts.id, condition_expression_params[consts.Consts.id])
             condition_expression.text = condition_expression_params[consts.Consts.condition_expression]
+            output_flow.set(consts.Consts.name, condition_expression_params[consts.Consts.condition_expression])
 
     @staticmethod
     def export_flow_di_data(params, plane):
